@@ -17,16 +17,14 @@ Data::Trace - Trace when a data structure gets updated.
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
-TODO
-
     use Data::Trace;
 
     my $data = {a => [0, {complex => 1}]};
@@ -96,10 +94,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Data::Trace
 
-=head1 ACKNOWLEDGEMENTS
-
-TBD
-
 =head1 LICENSE AND COPYRIGHT
 
 This software is Copyright (c) 2022 by Tim Potapov.
